@@ -2,7 +2,8 @@ require(quanteda)
 
 dict_newsmap <- dictionary(file = "../data/dictionary.yml")
 
-toks_test <- tokens(data_corpus_inaugural, remove_punct = TRUE)
+corp_test <- head(data_corpus_inaugural, 60)
+toks_test <- tokens(corp_test, remove_punct = TRUE)
 dfmt_test <- dfm(toks_test) %>%
     dfm_remove(stopwords("en"))
 toks_dict_test <- tokens_lookup(toks_test, dict_newsmap, level = 3)
@@ -302,11 +303,11 @@ test_that("coef() and dictionary() are working", {
     expect_error(coef(map, select = "xx"),
                  "Selected class must be in the model")
     expect_error(coef(map, select = character()),
-                 "The length of select must be between 1 and 16")
+                 "The length of select must be between 1 and 17")
 
     # TODO: remove as.list()
     lis1 <- as.list(map)
-    expect_equal(length(lis1), 16)
+    expect_equal(length(lis1), 17)
     expect_true(all(sapply(lis1, is.character)))
     expect_true(all(lengths(as.list(lis1)) == 10))
 
