@@ -11,19 +11,21 @@ test_that("textplot_terms works with dictionary", {
 
     wmp1 <- textmodel_wordmap(dfmt_test, smat_test)
 
-    expect_silent(print(
+    expect_true(is_ggplot(
         textplot_terms(wmp1, data_dictionary_LSD2015, max_highlighted = 10)
     ))
-    expect_silent(print(
+
+    expect_true(is_ggplot(
         textplot_terms(wmp1, dictionary(list(none = "xxxxx")))
     ))
 
     wmp2 <- textmodel_wordmap(dfmt_test, smat_test, entropy = "global")
 
-    expect_silent(print(
+    expect_true(is_ggplot(
         textplot_terms(wmp2, data_dictionary_LSD2015, max_highlighted = 10)
     ))
-    expect_silent(print(
+
+    expect_true(is_ggplot(
         textplot_terms(wmp2, dictionary(list(none = "xxxxx")))
     ))
 })
